﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class PlayerController : MonoBehaviour
{

	public RectTransform healthBar;
	public RectTransform energyBar;

	public AudioClip plasmaCannonShoot;
	public AudioClip plasmaCannonHit;

	AudioSource ASource;

	public int maxHealth = 100;
	[HideInInspector]public int health;

	public int maxEnergy = 100;
	[HideInInspector]public int energy;

	void Awake ()
	{
		ASource = GetComponent<AudioSource> ();
	}

	void Start ()
	{
		health = maxHealth;
		energy = maxEnergy;
		StartCoroutine (HealShip ());

		updateSprite (GameObject.Find ("MenuManager").GetComponent<MenuManager> ().ship);
	}

	void OnTriggerEnter2D (Collider2D other)
	{
		if (other.tag == "EProjectile") {
			TakeDamage (5);
		} else if (other.tag == "Battery") {
			RemoveEnergy (-maxEnergy);
			AudioSource.PlayClipAtPoint (other.GetComponent<AudioSource> ().clip, other.transform.position, 1);
			Destroy (other.gameObject);
		} else if (other.tag == "Repair") {
			Repair (maxHealth / 4);
			AudioSource.PlayClipAtPoint (other.GetComponent<AudioSource> ().clip, other.transform.position, 1);
			Destroy (other.gameObject);
		}

	}

	public void TakeDamage (int amount)
	{
		health -= amount;
		playSound ("PC_Hit");
		if (health < 0) {
			health = 0;
			StartCoroutine (GameObject.Find ("WorldController").GetComponent<GameManager> ().displayGameOver ());
		}
		updateHealthbar ();
	}

	public void Repair (int amount)
	{
		health += amount;
		if (health > maxHealth) {
			health = maxHealth;
		}
		updateHealthbar ();
	}

	public void RemoveEnergy (int amount)
	{
		energy -= amount;
		if (energy < 0) {
			energy = 0;
		}
		if (energy > maxEnergy)
			energy = maxEnergy;
		updateEnergybar ();
	}

	IEnumerator HealShip ()
	{
		while (true) {
			Repair (1);
			RemoveEnergy (-5);
			yield return new WaitForSeconds (0.5f);
		}
	}

	public void playSound (string sound)
	{
		switch (sound) {
		case "PC_Shoot":
			ASource.PlayOneShot (plasmaCannonShoot, 1);
			break;

		case "PC_Hit":
			ASource.PlayOneShot (plasmaCannonHit, 1);
			break;
		}
	}

	void updateHealthbar ()
	{
		float barScale = (float)health / maxHealth;
		if (barScale > 0) {
			healthBar.localScale = new Vector2 (barScale, 1);
			healthBar.GetComponent<Image> ().color = new Color (1 - barScale, barScale, 0);
		}
	}

	void updateEnergybar ()
	{
		float barScale = (float)energy / maxEnergy;
		if (barScale > 0) {
			energyBar.localScale = new Vector2 (barScale, 1);
			energyBar.GetComponent<Image> ().color = new Color (1 - barScale, barScale, barScale);
		}
	}

	public void updateSprite (Sprite newSprite)
	{
		GetComponent<SpriteRenderer> ().sprite = newSprite;
	}

}
